/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) INRIA - Bruno JOFFRET
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
#ifndef __ERRO_H__
#define __ERRO_H__

#include "machine.h"
#include "dynlib_output_stream.h"

OUTPUT_STREAM_IMPEXP int C2F(erro)(char *str,unsigned int str_len);

#endif /* !__ERRO_H__ */
